summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureBase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoPictureBase.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoPictureBase.h')
-rw-r--r--lib/kofficecore/KoPictureBase.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/lib/kofficecore/KoPictureBase.h b/lib/kofficecore/KoPictureBase.h
index 17a7df96..73056aa6 100644
--- a/lib/kofficecore/KoPictureBase.h
+++ b/lib/kofficecore/KoPictureBase.h
@@ -22,14 +22,14 @@
#include "KoPictureKey.h" // for KoPictureType
-#include <qstring.h>
-#include <qimage.h>
+#include <tqstring.h>
+#include <tqimage.h>
class KoXmlWriter;
-class QPainter;
-class QSize;
-class QIODevice;
-class QDragObject;
+class TQPainter;
+class TQSize;
+class TQIODevice;
+class TQDragObject;
const char NULL_MIME_TYPE[]="application/x-zerosize";
@@ -70,30 +70,30 @@ public:
* Note that the image is being scaled to that size using scale() - except when printing.
* This avoids scaling the image at each paint event.
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the pixmap that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*/
- virtual void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
+ virtual void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
/**
* Create a dragobject containing this picture.
* @param dragSource must be 0 when copying to the clipboard
* @return 0L if the picture is null!
*/
- virtual QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
+ virtual TQDragObject* dragObject( TQWidget *dragSource = 0L, const char *name = 0L );
- virtual bool load(QIODevice* io, const QString& extension);
+ virtual bool load(TQIODevice* io, const TQString& extension);
- virtual bool loadData(const QByteArray& array, const QString& extension);
+ virtual bool loadData(const TQByteArray& array, const TQString& extension);
/**
* save file
* @param io QIODevice used for saving
*/
- virtual bool save(QIODevice* io) const;
+ virtual bool save(TQIODevice* io) const;
/**
* OASIS FlatXML support:
@@ -101,26 +101,26 @@ public:
*/
virtual bool saveAsBase64( KoXmlWriter& writer ) const;
- virtual QSize getOriginalSize(void) const;
+ virtual TQSize getOriginalSize(void) const;
- virtual QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ virtual TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
- virtual QString getMimeType(const QString& extension) const;
+ virtual TQString getMimeType(const TQString& extension) const;
bool isSlowResizeModeAllowed(void) const;
/**
- * Generate a QImage
+ * Generate a TQImage
* (always in slow mode)
*/
- virtual QImage generateImage(const QSize& size);
+ virtual TQImage generateImage(const TQSize& size);
virtual bool hasAlphaBuffer() const
{ return false; }
virtual void setAlphaBuffer(bool /*enable*/)
{ }
- virtual QImage createAlphaMask(int /*conversion_flags*/ = 0) const
- { return QImage(); }
+ virtual TQImage createAlphaMask(int /*conversion_flags*/ = 0) const
+ { return TQImage(); }
virtual void clearCache(void);
};
@@ -70,30 +70,30 @@ public:
* This avoids scaling the image at each paint event.
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
@@ -70,30 +70,30 @@ public:
/**
* save file
- * @param io QIODevice used for saving
+ * @param io TQIODevice used for saving
*/